<?php $TRANSLATIONS = array(
"Information about vCard is incorrect. Please reload the page." => "Podaci o vKarti su neispravni. Ponovo učitajte stranicu.",
"Edit" => "Uredi",
"Delete" => "Obriši",
"This is not your addressbook." => "Ovo nije vaš adresar.",
"Contact could not be found." => "Kontakt se ne može naći.",
"Work" => "Posao",
"Home" => "Kuća",
"Mobile" => "Mobilni",
"Text" => "Tekst",
"Voice" => "Glas",
"Fax" => "Faks",
"Video" => "Video",
"Pager" => "Pejdžer",
"Birthday" => "Rođendan",
"Add Contact" => "Dodaj kontakt",
"Organization" => "Organizacija",
"Phone" => "Telefon",
"Email" => "E-mail",
"Address" => "Adresa",
"PO Box" => "Poštanski broj",
"Extended" => "Proširi",
"City" => "Grad",
"Region" => "Regija",
"Zipcode" => "Zip kod",
"Country" => "Zemlja"
);
